@@ -333,6 +333,12 @@ class CollectionResource(BaseResource):
             raise falcon.errors.HTTPMethodNotAllowed(getattr(self, 'methods', ['GET', 'POST', 'PATCH']))
 
         with session_scope(self.db_engine, sessionmaker_=self.sessionmaker, **self.sessionmaker_kwargs) as db_session:
+            column_filters = kwargs
+            before_get = getattr(self, 'before_get', None)
+            if before_get is not None:
+                self.before_get(req, resp, db_session, column_filters, *args)
+            kwargs = column_filters
+
             extra_select    = getattr(self, 'extra_select', [])
             resources       = self.apply_arg_filter(req, resp, db_session.query(self.model, *extra_select), kwargs)
 
@@ -597,6 +603,12 @@ class SingleResource(BaseResource):
             raise falcon.errors.HTTPMethodNotAllowed(getattr(self, 'methods', ['GET', 'PUT', 'PATCH', 'DELETE']))
 
         with session_scope(self.db_engine, sessionmaker_=self.sessionmaker, **self.sessionmaker_kwargs) as db_session:
+            column_filters = kwargs
+            before_get = getattr(self, 'before_get', None)
+            if before_get is not None:
+                self.before_get(req, resp, db_session, column_filters, *args)
+            kwargs = column_filters
+
             extra_select    = getattr(self, 'extra_select', [])
             resources = self.apply_arg_filter(req, resp, db_session.query(self.model, *extra_select), kwargs)
 
